/*
 * Code for class POINTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po486.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {POINTER}.hash_code */
EIF_INTEGER_32 F1063_8211 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_INTEGER_32) F1031_8185(Current);
}

/* {POINTER}.is_default_pointer */
EIF_BOOLEAN F1063_8212 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) F1031_8190(Current);
}

/* {POINTER}.plus */
EIF_POINTER F1063_8213 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_POINTER) F1031_8191(Current, arg1);
}

/* {POINTER}.out */
EIF_REFERENCE F1063_8215 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) F1031_8202(Current);
}

void EIF_Minit486 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
